<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class CELAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Celsius (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'cel-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '10000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 4;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'CEL';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#262761';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xaaAEBE6Fe48E54f431b0C390CfaF0b017d09D42d';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x1553E4fFd42691631F0b85CF21db310C1b62012C';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/cel.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'celsius';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}