<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class CUSDTAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Compound USDT (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'cusdt-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '100000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'CUSDT';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#908AFB';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xf650C3d88D12dB855b8bf7D11Be6C55A4e07dCC9';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x51852897D2A209ABfecBfAc5EE43c562d2A88e82';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/cusdt.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'compound-usdt';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}