<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class ELFAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'ELF (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'elf-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ELF';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#2B5EBA';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xbf2179859fc6D5BEE9Bf9158632Dc51678a4100e';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xeC86F82883d81b65BE67a16E9dbbE534B0a975FE';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/elf.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'aelf';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}