<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class ILVAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Numeraire (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'ilv-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ILV';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#252755';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x767FE9EDC9E0dF98E07454847909b5E959D7ca0E';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xFb82c2ff685b6e1906258e0eB42b8A650Cd0267a';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/ilv.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'illuvium';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(0.01);
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000);
    }
}