<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class MATICAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Matic Token (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'matic-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'MATIC';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#8247E5';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x7D1AfA7B718fb893dB30A3aBc0Cfc608AaCfeBB0';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x33b9E0da766c85A97b2d259c6D7B12ABb5Ea6446';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/matic.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'polygon';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000);
    }
}