<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class OGNAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Origin Protocol (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'ogn-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'OGN';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#1A80FC';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x8207c1FfC5B6804F6024322CcF34F29c3541Ae26';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x93E4ebAe17135b428bDEcD46dD88FD1cB0B2b8F2';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/ogn.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'origin-protocol';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}