<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class PUNDIXAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Pundi X Token (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'pundix-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'PUNDIX';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#F6D30C';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x0FD10b9899882a6f2fcb5c371E17e70FdEe00C38';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x96af41f01773008200B6E59cFD0B0fa8D9104f4a';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/pundix.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'pundix-new';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}