<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class RSRAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Reserve Rights (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'rsr-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 4;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'RSR';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#F1FF50';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x320623b8E4fF03373931769A31Fc52A4E78B5d70';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x879CF2190ee8FCF0f9C4a6cA1269D47eA8E9666E';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/rsr.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'reserve-rights';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}