<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class SUSHIAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'SushiToken (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'sushi-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'SUSHI';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#E95AA7';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x6B3595068778DD592e39A122f4f5a5cF09C90fE2';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x47c9a820B33d4CEf10E6C276b4106E4A1C20AABc';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/sushi.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'sushiswap';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000);
    }
}