<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class USDCAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'USD Coin (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'usdc-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 6;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'USDC';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#2775CA';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x3585548C940ecb4343Ee0869eDFeE9f401bd4086';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/usdc.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'usd-coin';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000);
    }
}