<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class XDCEAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'XinFin XDCE (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'xdce-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'XDCE';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#234A81';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x41AB1b6fcbB2fA9DCEd81aCbdeC13Ea6315F2Bf2';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x9f30F40E6FBEca70A714d88E2D72Da2a72aea17F';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/xdce.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'xinfin-network';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}