<?php

namespace App\Plugins\EthereumBundle;

use App\CoinAdapters\Abstracts\AbstractEthereumTokenAdapter;
use Brick\Math\BigDecimal;

class YFIAdapter extends AbstractEthereumTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'yearn.finance (ERC)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'yfi-erc';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'YFI';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#0272ED';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xD7fF64620d970E9d6164EdB1A1f31CD95a8797a7';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/ethereum-bundle/yfi.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return 'yearn-finance';
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(0.00001);
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000);
    }
}